@@ -1,6 +1,7 @@
 """Constants for the Z-Wave JS python library."""
 from __future__ import annotations
 
+import logging
 from dataclasses import dataclass, field
 from enum import Enum, IntEnum
 from importlib import metadata
@@ -10,9 +11,9 @@ PACKAGE_NAME = "zwave-js-server-python"
 __version__ = metadata.version(PACKAGE_NAME)
 
 # minimal server schema version we can handle
-MIN_SERVER_SCHEMA_VERSION = 31
+MIN_SERVER_SCHEMA_VERSION = 32
 # max server schema version we can handle (and our code is compatible with)
-MAX_SERVER_SCHEMA_VERSION = 31
+MAX_SERVER_SCHEMA_VERSION = 32
 
 VALUE_UNKNOWN = "unknown"
 
@@ -52,6 +53,17 @@ class LogLevel(str, Enum):
     SILLY = "silly"
 
 
+LOG_LEVEL_MAP: dict[LogLevel, int] = {
+    LogLevel.ERROR: logging.ERROR,
+    LogLevel.WARN: logging.WARN,
+    LogLevel.INFO: logging.INFO,
+    LogLevel.HTTP: logging.INFO,
+    LogLevel.VERBOSE: logging.DEBUG,
+    LogLevel.DEBUG: logging.DEBUG,
+    LogLevel.SILLY: logging.DEBUG,
+}
+
+
 class CommandClass(IntEnum):
     """Enum with all known CommandClasses."""
 
