@@ -1,6 +1,8 @@
 """Provide a model for the Z-Wave JS controller's inclusion/provisioning data structures."""
+from __future__ import annotations
+
 from dataclasses import dataclass
-from typing import Any, Dict, List, Optional, TypedDict
+from typing import Any, TypedDict
 
 from ...const import Protocols, ProvisioningEntryStatus, QRCodeVersion, SecurityClass
 
@@ -9,7 +11,7 @@ class InclusionGrantDataType(TypedDict):
     """Representation of an inclusion grant data dict type."""
 
     # https://github.com/zwave-js/node-zwave-js/blob/master/packages/zwave-js/src/lib/controller/Inclusion.ts#L48-L56
-    securityClasses: List[int]
+    securityClasses: list[int]
     clientSideAuth: bool
 
 
@@ -17,7 +19,7 @@ class InclusionGrantDataType(TypedDict):
 class InclusionGrant:
     """Representation of an inclusion grant."""
 
-    security_classes: List[SecurityClass]
+    security_classes: list[SecurityClass]
     client_side_auth: bool
 
     def to_dict(self) -> InclusionGrantDataType:
@@ -43,12 +45,12 @@ class ProvisioningEntry:
     """Class to represent the base fields of a provisioning entry."""
 
     dsk: str
-    security_classes: List[SecurityClass]
-    requested_security_classes: Optional[List[SecurityClass]] = None
+    security_classes: list[SecurityClass]
+    requested_security_classes: list[SecurityClass] | None = None
     status: ProvisioningEntryStatus = ProvisioningEntryStatus.ACTIVE
-    additional_properties: Optional[Dict[str, Any]] = None
+    additional_properties: dict[str, Any] | None = None
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         """Return PlannedProvisioning data dict from self."""
         data = {
             "dsk": self.dsk,
@@ -63,7 +65,7 @@ class ProvisioningEntry:
         return data
 
     @classmethod
-    def from_dict(cls, data: Dict[str, Any]) -> "ProvisioningEntry":
+    def from_dict(cls, data: dict[str, Any]) -> "ProvisioningEntry":
         """Return ProvisioningEntry from data dict."""
         cls_instance = cls(
             dsk=data["dsk"],
@@ -98,16 +100,16 @@ class QRProvisioningInformationMixin:
     product_type: int
     product_id: int
     application_version: str
-    max_inclusion_request_interval: Optional[int]
-    uuid: Optional[str]
-    supported_protocols: Optional[List[Protocols]]
+    max_inclusion_request_interval: int | None
+    uuid: str | None
+    supported_protocols: list[Protocols] | None
 
 
 @dataclass
 class QRProvisioningInformation(ProvisioningEntry, QRProvisioningInformationMixin):
     """Representation of provisioning information retrieved from a QR code."""
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         """Return QRProvisioningInformation data dict from self."""
         data = {
             "version": self.version.value,
@@ -138,7 +140,7 @@ class QRProvisioningInformation(ProvisioningEntry, QRProvisioningInformationMixi
         return data
 
     @classmethod
-    def from_dict(cls, data: Dict[str, Any]) -> "QRProvisioningInformation":
+    def from_dict(cls, data: dict[str, Any]) -> "QRProvisioningInformation":
         """Return QRProvisioningInformation from data dict."""
         cls_instance = cls(
             version=QRCodeVersion(data["version"]),
